==> owncloud-8.2.1-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/activity/l10n/sl.js <==
OC.L10N.register(
    "activity",
    {
    "Activity" : "Dejavnosti",
    "Personal activity feed for %s" : "Osebne dejavnosti za %s",
    "Your feed URL is invalid" : "Spletni naslov vira ni veljaven",
    "Your settings have been updated." : "Nastavitve so posodobljene.",
    "Mail" : "Elektronska pošta",
    "Stream" : "Pretok",
    "Activities" : "Dejavnosti",
    "Error loading activities" : "Napaka nalaganja dejavnosti",
    "No activities" : "Ni dejavnosti",
    "This stream will show events like additions, changes & shares" : "V tem pretoku bodo pokazani dogodki, kot so dodajanja, spremembe in spreminjanje souporabe.",
    "There are no events for this filter" : "Ta filter ne pokaže nobenih dogodkov",
    "Activity notification" : "Obvestila o dejavnosti",
    "All Activities" : "Vse dejavnosti",
    "Activities by you" : "Vaše dejavnosti",
    "Activities by others" : "Dejavnosti drugih",
    "\"remote user\"" : "\"oddaljeni uporabnik\"",
    "in %s" : "v %s",
    "%s and %s" : "%s in %s",
    ", " : ",",
    "_%s and %n more_::_%s and %n more_" : ["%s in %n več","%s in %n več","%s in %n več","%s in %n več"],
    "Hello %s," : "Pozdravljeni, %s,",
    "* %1$s - %2$s" : "* %1$s - %2$s",
    "_* and %n more _::_* and %n more _" : ["* in %n dodaten","* in %n dodatna","* in %n dodatni","* in %n dodatnih"],
    "Notifications" : "Obvestila",
    "List your own actions in the stream" : "Izpiši seznam dejanj v pretoku",
    "Notify about your own actions via email" : "O mojih dejanjih me obvesti preko elektronske pošte",
    "You need to set up your email address before you can receive notification emails." : "Za prejemanje obvestil z elektronsko pošto, je treba najprej nastaviti elektronski poštni naslov.",
    "Send emails:" : "Pošlji elektronsko sporočilo:",
    "Hourly" : "Vsako uro",
    "Daily" : "Dnevno",
    "Weekly" : "Tedensko",
    "Activity feed" : "Objava dejavnosti z viri RSS",
    "Enable RSS feed" : "Omogoči vire RSS",
    "No activity yet" : "Ni zabeležene dejavnosti",
    "No more events to load" : "Ni več dogodkov za nalaganje",
    "Files" : "Datoteke"
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");

==> owncloud-9.1.1-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/activity/l10n/sl.js <==
OC.L10N.register(
    "activity",
    {
    "Activity" : "Dejavnosti",
    "Activities" : "Dejavnosti",
    "Error loading activities" : "Napaka nalaganja dejavnosti",
    "No activities" : "Ni dejavnosti",
    "Load more activities" : "Naloži več dejavnosti",
    ", " : ",",
    "{parameterList} and {lastParameter}" : "{parameterList} in {lastParameter}",
    "_{parameterList} and {linkStart}%n more{linkEnd}_::_{parameterList} and {linkStart}%n more{linkEnd}_" : ["{parameterList} in {linkStart}%n dodatna {linkEnd}","{parameterList} in {linkStart}%n dodatni {linkEnd}","{parameterList} in {linkStart}%n dodatne {linkEnd}","{parameterList} in {linkStart}%n dodatnih {linkEnd}"],
    "in {directory}" : "v {directory}",
    "This stream will show events like additions, changes & shares" : "V tem pretoku bodo pokazani dogodki, kot so dodajanja, spremembe in spreminjanje souporabe.",
    "There are no events for this filter" : "Ta filter ne pokaže nobenih dogodkov",
    "Today" : "Danes",
    "Yesterday" : "Včeraj",
    "Personal activity feed for %s" : "Osebne dejavnosti za %s",
    "Your feed URL is invalid" : "Spletni naslov vira ni veljaven",
    "Your settings have been updated." : "Nastavitve so posodobljene.",
    "Mail" : "Elektronska pošta",
    "Stream" : "Pretok",
    "\"remote user\"" : "\"oddaljeni uporabnik\"",
    "Activity notification" : "Obvestila o dejavnosti",
    "All Activities" : "Vse dejavnosti",
    "Activities by you" : "Vaše dejavnosti",
    "Activities by others" : "Dejavnosti drugih",
    "%s and %s" : "%s in %s",
    "Hello %s," : "Pozdravljeni, %s,",
    "You are receiving this email because the following things happened at %s" : "To sporočilo ste prejeli, ker so se zgodili naslednji dogodki na %s",
    "* %1$s - %2$s" : "* %1$s - %2$s",
    "_* and %n more _::_* and %n more _" : ["* in %n dodaten","* in %n dodatna","* in %n dodatni","* in %n dodatnih"],
    "List your own file actions in the stream" : "Izpiši seznam datotečnih opravil v pretoku",
    "Notify about your own actions via email" : "O mojih dejanjih me obvesti preko elektronske pošte",
    "You need to set up your email address before you can receive notification emails." : "Za prejemanje obvestil prek elektronske pošte je treba najprej nastaviti elektronski poštni naslov.",
    "Send emails:" : "Pošlji elektronsko sporočilo:",
    "Hourly" : "Vsako uro",
    "Daily" : "Dnevno",
    "Weekly" : "Tedensko",
    "Activity feed" : "Objava dejavnosti z viri RSS",
    "Enable RSS feed" : "Omogoči vire RSS",
    "No activity yet" : "Ni zabeležene dejavnosti",
    "No more events to load" : "Ni več dogodkov za nalaganje",
    "Files" : "Datoteke"
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
